import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  max,
  axisLeft,
  axisBottom,
  area,
  curveBasis,
  format
} from 'd3';// importing the library

const svg = select('svg');//  creating the svg image

const height = +svg.attr('height');// measurements of the graph
const width = +svg.attr('width');

const render = data => {// for drawing the x
  const title = 'Data of Android Users.';
  const xValue = d => d.Years;
  const xAxisLabel = 'Years';
  
	const yValue = d => d.users;// for keeping the y vaules 
  const circleRadius = 6;
  const yAxisLabel = 'users';
  
  const margin = {top: 60, right: 50, bottom: 88, left:110}// for the graph margin 
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleTime()// for keeping the x values
  .domain(extent(data, xValue))
  .range([0,innerWidth])
  .nice()
  
  const yScale = scaleLinear()// for keeping the y values
  .domain([0,max(data, yValue)])
  .range([innerHeight,0])
  .nice()
  
  const g = svg.append('g') //for appending the margin
  .attr('transform', `translate(${margin.left},${margin.top})`)
  
  const xAxis = axisBottom(xScale)// for the values in x axis
  .ticks(6)
  .tickSize(-innerHeight)
  .tickPadding(15)
  
  const yAxisTickFormat = number => 
  format('.1s')(number)
  .replace('G','B');
  
  const yAxis = axisLeft(yScale) // for the values in y axis
    .tickSize(-innerWidth)
  .tickPadding(10)
  .tickFormat(yAxisTickFormat);
  
  const yAxisG = g.append('g')
    .call(yAxis);
  
  yAxisG
  .selectAll('.domain')
          .remove()
  
  yAxisG.append('text')//for filling the color in the graph
  .attr('class', 'axis-label')
  .attr('fill', 'black')
  .attr('x', -innerHeight/ 2)
  .attr('y', -63)
  .attr('transform', `rotate(-90)`)
  .attr('text-anchor', 'middle')
  .text(yAxisLabel)
  
  
  const xAxisG = g.append('g').call(xAxis) // for getting the values in x axis
  .attr('transform', `translate(0,${innerHeight})`)
    
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')// for filling on y axis
  .attr('class', 'axis-label')
  .attr('fill', 'black')
  .attr('x', innerWidth / 2)
  .attr('y', 75)
  .text(xAxisLabel)
  
  const areaGenerator = area() // for the values in x and y values
  .x(d => xScale(xValue(d)))
  .y0(innerHeight)
  .y1(d => yScale(yValue(d)))
  .curve(curveBasis)
  
  g.append('path')
  .attr('class', 'line-path')
  .attr('d', areaGenerator(data));

  svg.append('text')// for x values
  	.attr('class', 'title')
  .attr('x', width / 2)
  .attr('text-anchor', 'middle')
  	.attr('y', 45)
  	.text(title)
}

csv('https://gist.githubusercontent.com/VReddy913/55d1f5359f17737d934242141d7faed9/raw/a7f36fa90074ea07b1e20a3514fe6235db9b240b/ICE7-4.csv')
.then(data => {// for connecting the database
  console.log(data);
  data.forEach(d => {
    d.users= +d.users;
    d.Years = d3.timeParse("%Y-%m-%d")(d.Years);
  });
  render(data);
});